==> SingleRBook_1.2.0.tar.gz: SingleRBook/inst/doc/book/brain.md <==
---
bibliography: ref.bib
---

# Cross-annotating mouse brains

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the classic @zeisel2015brain dataset as our reference.
Here, we'll rely on the fact that the authors have already performed quality control.


```r
library(scRNAseq)
sceZ <- ZeiselBrainData()
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceZ <- logNormCounts(sceZ)
```

We examine the distribution of labels in this reference.


```r
table(sceZ$level2class)
```

```
## 
##    (none)    Astro1    Astro2   CA1Pyr1   CA1Pyr2 CA1PyrInt   CA2Pyr2   Choroid 
##       189        68        61       380       447        49        41        10 
##   ClauPyr     Epend      Int1     Int10     Int11     Int12     Int13     Int14 
##         5        20        12        21        10        21        15        22 
##     Int15     Int16      Int2      Int3      Int4      Int5      Int6      Int7 
##        18        20        24        10        15        20        22        23 
##      Int8      Int9      Mgl1      Mgl2    Oligo1    Oligo2    Oligo3    Oligo4 
##        26        11        17        16        45        98        87       106 
##    Oligo5    Oligo6     Peric      Pvm1      Pvm2   S1PyrDL  S1PyrL23   S1PyrL4 
##       125       359        21        32        33        81        74        26 
##   S1PyrL5  S1PyrL5a   S1PyrL6  S1PyrL6b    SubPyr     Vend1     Vend2      Vsmc 
##        16        28        39        21        22        32       105        62
```

We load the @tasic2016adult dataset as our test.
While not strictly necessary, we remove putative low-quality cells to simplify later interpretation.


```r
sceT <- TasicBrainData()
sceT <- addPerCellQC(sceT, subsets=list(mito=grep("^mt_", rownames(sceT))))
qc <- quickPerCellQC(colData(sceT), 
    percent_subsets=c("subsets_mito_percent", "altexps_ERCC_percent"))
sceT <- sceT[,which(!qc$discard)]
```

The Tasic dataset was generated using read-based technologies so we need to adjust for the transcript length.


```r
library(AnnotationHub)
mm.db <- AnnotationHub()[["AH73905"]]
mm.exons <- exonsBy(mm.db, by="gene")
mm.exons <- reduce(mm.exons)
mm.len <- sum(width(mm.exons))
mm.symb <- mapIds(mm.db, keys=names(mm.len), keytype="GENEID", column="SYMBOL")
names(mm.len) <- mm.symb

library(scater)
keep <- intersect(names(mm.len), rownames(sceT))
sceT <- sceT[keep,]
assay(sceT, "TPM") <- calculateTPM(sceT, lengths=mm.len[keep])
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Tasic dataset with the Zeisel labels.


```r
library(SingleR)
pred.tasic <- SingleR(test=sceT, ref=sceZ, labels=sceZ$level2class, 
    assay.type.test="TPM", de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.tasic$labels)
```

```
## 
##   Astro1   Astro2  CA1Pyr2  CA2Pyr2  ClauPyr     Int1    Int10    Int11 
##        1        5        1        3        1      152       98        2 
##    Int12    Int13    Int14    Int15    Int16     Int2     Int3     Int4 
##        9       18       24       16       10      146       94       29 
##     Int6     Int7     Int8     Int9   Oligo1   Oligo2   Oligo3   Oligo4 
##       14        2       35       31        8        1        7        1 
##   Oligo6    Peric  S1PyrDL S1PyrL23  S1PyrL4  S1PyrL5 S1PyrL5a  S1PyrL6 
##        1        1      319       73       16        4      201       46 
## S1PyrL6b   SubPyr 
##       73        5
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.tasic$labels,
    Lost=is.na(pred.tasic$pruned.labels))
```

```
##           Lost
## Label      FALSE TRUE
##   Astro1       1    0
##   Astro2       5    0
##   CA1Pyr2      1    0
##   CA2Pyr2      3    0
##   ClauPyr      1    0
##   Int1       152    0
##   Int10       98    0
##   Int11        2    0
##   Int12        9    0
##   Int13       18    0
##   Int14       23    1
##   Int15       16    0
##   Int16       10    0
##   Int2       144    2
##   Int3        94    0
##   Int4        29    0
##   Int6        14    0
##   Int7         2    0
##   Int8        35    0
##   Int9        31    0
##   Oligo1       8    0
##   Oligo2       1    0
##   Oligo3       7    0
##   Oligo4       1    0
##   Oligo6       1    0
##   Peric        1    0
##   S1PyrDL    303   16
##   S1PyrL23    73    0
##   S1PyrL4     16    0
##   S1PyrL5      4    0
##   S1PyrL5a   200    1
##   S1PyrL6     45    1
##   S1PyrL6b    72    1
##   SubPyr       5    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-brain-score-heatmap).


```r
plotScoreHeatmap(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="960" />
<p class="caption">(\#fig:unref-brain-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-brain-delta-dist).


```r
plotDeltaDistribution(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="960" />
<p class="caption">(\#fig:unref-brain-delta-dist)Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for the most frequent label in Figure \@ref(fig:unref-brain-marker-heat).
We could show these for all labels but I wouldn't want to bore you with a parade of large heatmaps. 


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.tasic)$de.genes

sceT <- logNormCounts(sceT)
top.label <- names(sort(table(pred.tasic$labels), decreasing=TRUE))[1]

per.label <- sumCountsAcrossCells(logcounts(sceT), 
    ids=pred.tasic$labels, average=TRUE)
per.label <- assay(per.label)[unique(unlist(all.markers[[top.label]])),]
pheatmap::pheatmap(per.label, main=top.label)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-marker-heat-1.png" alt="Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset." width="960" />
<p class="caption">(\#fig:unref-brain-marker-heat)Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering.


```r
library(scran)
decT <- modelGeneVarWithSpikes(sceT, "ERCC")

set.seed(1000100)
sceT <- denoisePCA(sceT, decT, subset.row=getTopHVGs(decT, n=2500))

library(bluster)
sceT$cluster <- clusterRows(reducedDim(sceT, "PCA"), NNGraphParam())
```

We do not observe a clean 1:1 mapping between clusters and labels in Figure \@ref(fig:unref-brain-label-clusters),
probably because many of the labels represent closely related cell types that are difficult to distinguish.


```r
tab <- table(cluster=sceT$cluster, label=pred.tasic$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset." width="672" />
<p class="caption">(\#fig:unref-brain-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset.</p>
</div>

We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-brain-label-tsne)).


```r
set.seed(101010100)
sceT <- runTSNE(sceT, dimred="PCA")
plotTSNE(sceT, colour_by="cluster", text_colour="red",
    text_by=I(pred.tasic$labels))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-tsne-1.png" alt="$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-brain-label-tsne)$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.1.0 (2021-05-18)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.13-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.13-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats4    stats     graphics  grDevices utils     datasets 
[8] methods   base     

other attached packages:
 [1] bluster_1.2.0               scran_1.20.0               
 [3] SingleR_1.6.1               ensembldb_2.16.0           
 [5] AnnotationFilter_1.16.0     GenomicFeatures_1.44.0     
 [7] AnnotationDbi_1.54.0        AnnotationHub_3.0.0        
 [9] BiocFileCache_2.0.0         dbplyr_2.1.1               
[11] scater_1.20.0               ggplot2_3.3.3              
[13] scuttle_1.2.0               scRNAseq_2.6.0             
[15] SingleCellExperiment_1.14.1 SummarizedExperiment_1.22.0
[17] Biobase_2.52.0              GenomicRanges_1.44.0       
[19] GenomeInfoDb_1.28.0         IRanges_2.26.0             
[21] S4Vectors_0.30.0            BiocGenerics_0.38.0        
[23] MatrixGenerics_1.4.0        matrixStats_0.58.0         
[25] BiocStyle_2.20.0            rebook_1.2.0               

loaded via a namespace (and not attached):
  [1] igraph_1.2.6                  lazyeval_0.2.2               
  [3] BiocParallel_1.26.0           digest_0.6.27                
  [5] htmltools_0.5.1.1             viridis_0.6.1                
  [7] fansi_0.4.2                   magrittr_2.0.1               
  [9] memoise_2.0.0                 ScaledMatrix_1.0.0           
 [11] cluster_2.1.2                 limma_3.48.0                 
 [13] Biostrings_2.60.0             prettyunits_1.1.1            
 [15] colorspace_2.0-1              blob_1.2.1                   
 [17] rappdirs_0.3.3                xfun_0.23                    
 [19] dplyr_1.0.6                   crayon_1.4.1                 
 [21] RCurl_1.98-1.3                jsonlite_1.7.2               
 [23] graph_1.70.0                  glue_1.4.2                   
 [25] gtable_0.3.0                  zlibbioc_1.38.0              
 [27] XVector_0.32.0                DelayedArray_0.18.0          
 [29] BiocSingular_1.8.0            scales_1.1.1                 
 [31] pheatmap_1.0.12               edgeR_3.34.0                 
 [33] DBI_1.1.1                     Rcpp_1.0.6                   
 [35] viridisLite_0.4.0             xtable_1.8-4                 
 [37] progress_1.2.2                dqrng_0.3.0                  
 [39] bit_4.0.4                     rsvd_1.0.5                   
 [41] metapod_1.0.0                 httr_1.4.2                   
 [43] RColorBrewer_1.1-2            dir.expiry_1.0.0             
 [45] ellipsis_0.3.2                farver_2.1.0                 
 [47] pkgconfig_2.0.3               XML_3.99-0.6                 
 [49] CodeDepends_0.6.5             sass_0.4.0                   
 [51] locfit_1.5-9.4                utf8_1.2.1                   
 [53] labeling_0.4.2                tidyselect_1.1.1             
 [55] rlang_0.4.11                  later_1.2.0                  
 [57] munsell_0.5.0                 BiocVersion_3.13.1           
 [59] tools_4.1.0                   cachem_1.0.5                 
 [61] generics_0.1.0                RSQLite_2.2.7                
 [63] ExperimentHub_2.0.0           evaluate_0.14                
 [65] stringr_1.4.0                 fastmap_1.1.0                
 [67] yaml_2.2.1                    knitr_1.33                   
 [69] bit64_4.0.5                   purrr_0.3.4                  
 [71] KEGGREST_1.32.0               sparseMatrixStats_1.4.0      
 [73] mime_0.10                     biomaRt_2.48.0               
 [75] compiler_4.1.0                beeswarm_0.3.1               
 [77] filelock_1.0.2                curl_4.3.1                   
 [79] png_0.1-7                     interactiveDisplayBase_1.30.0
 [81] statmod_1.4.36                tibble_3.1.2                 
 [83] bslib_0.2.5.1                 stringi_1.6.2                
 [85] highr_0.9                     lattice_0.20-44              
 [87] ProtGenerics_1.24.0           Matrix_1.3-3                 
 [89] vctrs_0.3.8                   pillar_1.6.1                 
 [91] lifecycle_1.0.0               BiocManager_1.30.15          
 [93] jquerylib_0.1.4               BiocNeighbors_1.10.0         
 [95] cowplot_1.1.1                 bitops_1.0-7                 
 [97] irlba_2.3.3                   httpuv_1.6.1                 
 [99] rtracklayer_1.52.0            R6_2.5.0                     
[101] BiocIO_1.2.0                  bookdown_0.22                
[103] promises_1.2.0.1              gridExtra_2.3                
[105] vipor_0.4.5                   codetools_0.2-18             
[107] assertthat_0.2.1              rjson_0.2.20                 
[109] withr_2.4.2                   GenomicAlignments_1.28.0     
[111] Rsamtools_2.8.0               GenomeInfoDbData_1.2.6       
[113] hms_1.1.0                     grid_4.1.0                   
[115] beachmat_2.8.0                rmarkdown_2.8                
[117] DelayedMatrixStats_1.14.0     Rtsne_0.15                   
[119] shiny_1.6.0                   ggbeeswarm_0.6.0             
[121] restfulr_0.0.13              
```
</div>

==> SingleRBook_1.8.0.tar.gz: SingleRBook/inst/doc/book/brain.md <==
---
bibliography: ref.bib
---

# Cross-annotating mouse brains

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the classic @zeisel2015brain dataset as our reference.
Here, we'll rely on the fact that the authors have already performed quality control.


```r
library(scRNAseq)
sceZ <- ZeiselBrainData()
```

We compute log-expression values for use in marker detection inside `SingleR()`.


```r
library(scater)
sceZ <- logNormCounts(sceZ)
```

We examine the distribution of labels in this reference.


```r
table(sceZ$level2class)
```

```
## 
##    (none)    Astro1    Astro2   CA1Pyr1   CA1Pyr2 CA1PyrInt   CA2Pyr2   Choroid 
##       189        68        61       380       447        49        41        10 
##   ClauPyr     Epend      Int1     Int10     Int11     Int12     Int13     Int14 
##         5        20        12        21        10        21        15        22 
##     Int15     Int16      Int2      Int3      Int4      Int5      Int6      Int7 
##        18        20        24        10        15        20        22        23 
##      Int8      Int9      Mgl1      Mgl2    Oligo1    Oligo2    Oligo3    Oligo4 
##        26        11        17        16        45        98        87       106 
##    Oligo5    Oligo6     Peric      Pvm1      Pvm2   S1PyrDL  S1PyrL23   S1PyrL4 
##       125       359        21        32        33        81        74        26 
##   S1PyrL5  S1PyrL5a   S1PyrL6  S1PyrL6b    SubPyr     Vend1     Vend2      Vsmc 
##        16        28        39        21        22        32       105        62
```

We load the @tasic2016adult dataset as our test.
While not strictly necessary, we remove putative low-quality cells to simplify later interpretation.


```r
sceT <- TasicBrainData()
sceT <- addPerCellQC(sceT, subsets=list(mito=grep("^mt_", rownames(sceT))))
qc <- quickPerCellQC(colData(sceT), 
    percent_subsets=c("subsets_mito_percent", "altexps_ERCC_percent"))
sceT <- sceT[,which(!qc$discard)]
```

The Tasic dataset was generated using read-based technologies so we need to adjust for the transcript length.


```r
library(AnnotationHub)
mm.db <- AnnotationHub()[["AH73905"]]
mm.exons <- exonsBy(mm.db, by="gene")
mm.exons <- reduce(mm.exons)
mm.len <- sum(width(mm.exons))
mm.symb <- mapIds(mm.db, keys=names(mm.len), keytype="GENEID", column="SYMBOL")
names(mm.len) <- mm.symb

library(scater)
keep <- intersect(names(mm.len), rownames(sceT))
sceT <- sceT[keep,]
assay(sceT, "TPM") <- calculateTPM(sceT, lengths=mm.len[keep])
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Tasic dataset with the Zeisel labels.


```r
library(SingleR)
pred.tasic <- SingleR(test=sceT, ref=sceZ, labels=sceZ$level2class, 
    assay.type.test="TPM", de.method="wilcox")
```

We examine the distribution of predicted labels:


```r
table(pred.tasic$labels)
```

```
## 
##   Astro1   Astro2  CA1Pyr2  CA2Pyr2  ClauPyr     Int1    Int10    Int11 
##        1        5        1        3        1      152       98        2 
##    Int12    Int13    Int14    Int15    Int16     Int2     Int3     Int4 
##        9       18       24       16       10      146       94       29 
##     Int6     Int7     Int8     Int9   Oligo1   Oligo2   Oligo3   Oligo4 
##       14        2       35       31        8        1        7        1 
##   Oligo6    Peric  S1PyrDL S1PyrL23  S1PyrL4  S1PyrL5 S1PyrL5a  S1PyrL6 
##        1        1      320       73       16        4      201       46 
## S1PyrL6b   SubPyr 
##       72        5
```

We can also examine the number of discarded cells for each label:


```r
table(Label=pred.tasic$labels,
    Lost=is.na(pred.tasic$pruned.labels))
```

```
##           Lost
## Label      FALSE TRUE
##   Astro1       1    0
##   Astro2       5    0
##   CA1Pyr2      1    0
##   CA2Pyr2      3    0
##   ClauPyr      1    0
##   Int1       152    0
##   Int10       98    0
##   Int11        2    0
##   Int12        9    0
##   Int13       18    0
##   Int14       23    1
##   Int15       16    0
##   Int16       10    0
##   Int2       144    2
##   Int3        94    0
##   Int4        29    0
##   Int6        14    0
##   Int7         2    0
##   Int8        35    0
##   Int9        31    0
##   Oligo1       8    0
##   Oligo2       1    0
##   Oligo3       7    0
##   Oligo4       1    0
##   Oligo6       1    0
##   Peric        1    0
##   S1PyrDL    304   16
##   S1PyrL23    73    0
##   S1PyrL4     16    0
##   S1PyrL5      4    0
##   S1PyrL5a   200    1
##   S1PyrL6     45    1
##   S1PyrL6b    72    0
##   SubPyr       5    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-brain-score-heatmap).


```r
plotScoreHeatmap(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="960" />
<p class="caption">(\#fig:unref-brain-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Tasic test dataset with respect to each label (row) in the Zeisel reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-brain-delta-dist).


```r
plotDeltaDistribution(pred.tasic)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="960" />
<p class="caption">(\#fig:unref-brain-delta-dist)Distributions of the deltas for each cell in the Tasic dataset assigned to each label in the Zeisel dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for the most frequent label in Figure \@ref(fig:unref-brain-marker-heat).
We could show these for all labels but I wouldn't want to bore you with a parade of large heatmaps. 


```r
library(scater)
collected <- list()
all.markers <- metadata(pred.tasic)$de.genes

sceT <- logNormCounts(sceT)
top.label <- names(sort(table(pred.tasic$labels), decreasing=TRUE))[1]

per.label <- sumCountsAcrossCells(logcounts(sceT), 
    ids=pred.tasic$labels, average=TRUE)
per.label <- assay(per.label)[unique(unlist(all.markers[[top.label]])),]
pheatmap::pheatmap(per.label, main=top.label)
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-marker-heat-1.png" alt="Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset." width="960" />
<p class="caption">(\#fig:unref-brain-marker-heat)Heatmap of log-expression values in the Tasic dataset for all marker genes upregulated in the most frequent label from the Zeisel reference dataset.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering.


```r
library(scran)
decT <- modelGeneVarWithSpikes(sceT, "ERCC")

set.seed(1000100)
sceT <- denoisePCA(sceT, decT, subset.row=getTopHVGs(decT, n=2500))

library(bluster)
sceT$cluster <- clusterRows(reducedDim(sceT, "PCA"), NNGraphParam())
```

We do not observe a clean 1:1 mapping between clusters and labels in Figure \@ref(fig:unref-brain-label-clusters),
probably because many of the labels represent closely related cell types that are difficult to distinguish.


```r
tab <- table(cluster=sceT$cluster, label=pred.tasic$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset." width="672" />
<p class="caption">(\#fig:unref-brain-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Tasic dataset.</p>
</div>

We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-brain-label-tsne)).


```r
set.seed(101010100)
sceT <- runTSNE(sceT, dimred="PCA")
plotTSNE(sceT, colour_by="cluster", text_colour="red",
    text_by=I(pred.tasic$labels))
```

<div class="figure">
<img src="brain_files/figure-html/unref-brain-label-tsne-1.png" alt="$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-brain-label-tsne)$t$-SNE plot of the Tasic dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Zeisel dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.2.1 (2022-06-23)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 20.04.5 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.16-bioc/R/lib/libRblas.so
LAPACK: /home/biocbuild/bbs-3.16-bioc/R/lib/libRlapack.so

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.8.0               scran_1.26.0               
 [3] SingleR_2.0.0               ensembldb_2.22.0           
 [5] AnnotationFilter_1.22.0     GenomicFeatures_1.50.0     
 [7] AnnotationDbi_1.60.0        AnnotationHub_3.6.0        
 [9] BiocFileCache_2.6.0         dbplyr_2.2.1               
[11] scater_1.26.0               ggplot2_3.3.6              
[13] scuttle_1.8.0               scRNAseq_2.11.0            
[15] SingleCellExperiment_1.20.0 SummarizedExperiment_1.28.0
[17] Biobase_2.58.0              GenomicRanges_1.50.0       
[19] GenomeInfoDb_1.34.0         IRanges_2.32.0             
[21] S4Vectors_0.36.0            BiocGenerics_0.44.0        
[23] MatrixGenerics_1.10.0       matrixStats_0.62.0         
[25] BiocStyle_2.26.0            rebook_1.8.0               

loaded via a namespace (and not attached):
  [1] igraph_1.3.5                  lazyeval_0.2.2               
  [3] BiocParallel_1.32.0           digest_0.6.30                
  [5] htmltools_0.5.3               viridis_0.6.2                
  [7] fansi_1.0.3                   magrittr_2.0.3               
  [9] memoise_2.0.1                 ScaledMatrix_1.6.0           
 [11] cluster_2.1.4                 limma_3.54.0                 
 [13] Biostrings_2.66.0             prettyunits_1.1.1            
 [15] colorspace_2.0-3              blob_1.2.3                   
 [17] rappdirs_0.3.3                ggrepel_0.9.1                
 [19] xfun_0.34                     dplyr_1.0.10                 
 [21] crayon_1.5.2                  RCurl_1.98-1.9               
 [23] jsonlite_1.8.3                graph_1.76.0                 
 [25] glue_1.6.2                    gtable_0.3.1                 
 [27] zlibbioc_1.44.0               XVector_0.38.0               
 [29] DelayedArray_0.24.0           BiocSingular_1.14.0          
 [31] scales_1.2.1                  pheatmap_1.0.12              
 [33] edgeR_3.40.0                  DBI_1.1.3                    
 [35] Rcpp_1.0.9                    viridisLite_0.4.1            
 [37] xtable_1.8-4                  progress_1.2.2               
 [39] dqrng_0.3.0                   bit_4.0.4                    
 [41] rsvd_1.0.5                    metapod_1.6.0                
 [43] httr_1.4.4                    RColorBrewer_1.1-3           
 [45] dir.expiry_1.6.0              ellipsis_0.3.2               
 [47] farver_2.1.1                  pkgconfig_2.0.3              
 [49] XML_3.99-0.12                 CodeDepends_0.6.5            
 [51] sass_0.4.2                    locfit_1.5-9.6               
 [53] utf8_1.2.2                    labeling_0.4.2               
 [55] tidyselect_1.2.0              rlang_1.0.6                  
 [57] later_1.3.0                   munsell_0.5.0                
 [59] BiocVersion_3.16.0            tools_4.2.1                  
 [61] cachem_1.0.6                  cli_3.4.1                    
 [63] generics_0.1.3                RSQLite_2.2.18               
 [65] ExperimentHub_2.6.0           evaluate_0.17                
 [67] stringr_1.4.1                 fastmap_1.1.0                
 [69] yaml_2.3.6                    knitr_1.40                   
 [71] bit64_4.0.5                   purrr_0.3.5                  
 [73] KEGGREST_1.38.0               sparseMatrixStats_1.10.0     
 [75] mime_0.12                     xml2_1.3.3                   
 [77] biomaRt_2.54.0                compiler_4.2.1               
 [79] beeswarm_0.4.0                filelock_1.0.2               
 [81] curl_4.3.3                    png_0.1-7                    
 [83] interactiveDisplayBase_1.36.0 statmod_1.4.37               
 [85] tibble_3.1.8                  bslib_0.4.0                  
 [87] stringi_1.7.8                 highr_0.9                    
 [89] lattice_0.20-45               ProtGenerics_1.30.0          
 [91] Matrix_1.5-1                  vctrs_0.5.0                  
 [93] pillar_1.8.1                  lifecycle_1.0.3              
 [95] BiocManager_1.30.19           jquerylib_0.1.4              
 [97] BiocNeighbors_1.16.0          cowplot_1.1.1                
 [99] bitops_1.0-7                  irlba_2.3.5.1                
[101] httpuv_1.6.6                  rtracklayer_1.58.0           
[103] R6_2.5.1                      BiocIO_1.8.0                 
[105] bookdown_0.29                 promises_1.2.0.1             
[107] gridExtra_2.3                 vipor_0.4.5                  
[109] codetools_0.2-18              assertthat_0.2.1             
[111] rjson_0.2.21                  withr_2.5.0                  
[113] GenomicAlignments_1.34.0      Rsamtools_2.14.0             
[115] GenomeInfoDbData_1.2.9        parallel_4.2.1               
[117] hms_1.1.2                     grid_4.2.1                   
[119] beachmat_2.14.0               rmarkdown_2.17               
[121] DelayedMatrixStats_1.20.0     Rtsne_0.16                   
[123] shiny_1.7.3                   ggbeeswarm_0.6.0             
[125] restfulr_0.0.15              
```
</div>
